#
# Copyright (C) 2014-2022, AdaCore
# SPDX-License-Identifier: Apache-2.0
#

"""
This script is meant to be sourced inside GDB when debugging a program that
uses libadalang. It installs Langkit's "GDB helpers": pretty-printers and
custom commands that are convenient when debugging libadalang. Note that GDB
helpers require the Langkit Python library.
"""

import sys


sys.path.append('D:/a/msys64/mingw64/lib/python3.11/site-packages')


try:
    import langkit.gdb
except ImportError as exc:
    print(
        f"{__file__}: Cannot import the 'langkit.gdb' Python package: langkit"
        " GDB helpers require it",
        file=sys.stderr,
    )
else:
    
    langkit.gdb.setup(
        lib_name='libadalang',
        astnode_names=['Ada_Node', 'Abort_Node', 'Abort_Absent', 'Abort_Present', 'Abstract_Node', 'Abstract_Absent', 'Abstract_Present', 'Ada_List', 'Ada_Node_List', 'Abstract_State_Decl_List', 'Alternatives_List', 'Constraint_List', 'Decl_List', 'Stmt_List', 'Aspect_Assoc_List', 'Base_Assoc_List', 'Basic_Assoc_List', 'Assoc_List', 'Basic_Decl_List', 'Case_Expr_Alternative_List', 'Case_Stmt_Alternative_List', 'Compilation_Unit_List', 'Concat_Operand_List', 'Contract_Case_Assoc_List', 'Defining_Name_List', 'Discriminant_Spec_List', 'Elsif_Expr_Part_List', 'Elsif_Stmt_Part_List', 'Enum_Literal_Decl_List', 'Expr_List', 'Expr_Alternatives_List', 'Identifier_List', 'Discriminant_Choice_List', 'Name_List', 'Parent_List', 'Param_Spec_List', 'Pragma_Node_List', 'Select_When_Part_List', 'Unconstrained_Array_Index_List', 'Variant_List', 'Aliased_Node', 'Aliased_Absent', 'Aliased_Present', 'All_Node', 'All_Absent', 'All_Present', 'Array_Indices', 'Constrained_Array_Indices', 'Unconstrained_Array_Indices', 'Aspect_Assoc', 'Aspect_Clause', 'At_Clause', 'Attribute_Def_Clause', 'Enum_Rep_Clause', 'Record_Rep_Clause', 'Aspect_Spec', 'Base_Assoc', 'Contract_Case_Assoc', 'Pragma_Argument_Assoc', 'Base_Formal_Param_Holder', 'Base_Subp_Spec', 'Entry_Spec', 'Enum_Subp_Spec', 'Subp_Spec', 'Synthetic_Binary_Spec', 'Synthetic_Unary_Spec', 'Component_List', 'Discriminant_Part', 'Known_Discriminant_Part', 'Unknown_Discriminant_Part', 'Entry_Completion_Formal_Params', 'Generic_Formal_Part', 'Base_Record_Def', 'Null_Record_Def', 'Record_Def', 'Basic_Assoc', 'Aggregate_Assoc', 'Multi_Dim_Array_Assoc', 'Composite_Constraint_Assoc', 'Iterated_Assoc', 'Param_Assoc', 'Basic_Decl', 'Abstract_State_Decl', 'Anonymous_Expr_Decl', 'Base_Formal_Param_Decl', 'Component_Decl', 'Discriminant_Spec', 'Generic_Formal', 'Generic_Formal_Obj_Decl', 'Generic_Formal_Package', 'Generic_Formal_Subp_Decl', 'Generic_Formal_Type_Decl', 'Param_Spec', 'Synthetic_Formal_Param_Decl', 'Base_Package_Decl', 'Generic_Package_Internal', 'Package_Decl', 'Base_Type_Decl', 'Base_Subtype_Decl', 'Discrete_Base_Subtype_Decl', 'Subtype_Decl', 'Classwide_Type_Decl', 'Incomplete_Type_Decl', 'Incomplete_Formal_Type_Decl', 'Incomplete_Tagged_Type_Decl', 'Protected_Type_Decl', 'Task_Type_Decl', 'Single_Task_Type_Decl', 'Type_Decl', 'Anonymous_Type_Decl', 'Synth_Anonymous_Type_Decl', 'Concrete_Type_Decl', 'Formal_Type_Decl', 'Basic_Subp_Decl', 'Classic_Subp_Decl', 'Abstract_Subp_Decl', 'Formal_Subp_Decl', 'Abstract_Formal_Subp_Decl', 'Concrete_Formal_Subp_Decl', 'Subp_Decl', 'Entry_Decl', 'Enum_Literal_Decl', 'Synthetic_Char_Enum_Lit', 'Generic_Subp_Internal', 'Synthetic_Subp_Decl', 'Body_Node', 'Accept_Stmt_Body', 'Base_Subp_Body', 'Expr_Function', 'Null_Subp_Decl', 'Subp_Body', 'Subp_Renaming_Decl', 'Body_Stub', 'Package_Body_Stub', 'Protected_Body_Stub', 'Subp_Body_Stub', 'Task_Body_Stub', 'Entry_Body', 'Package_Body', 'Protected_Body', 'Task_Body', 'Entry_Index_Spec', 'Error_Decl', 'Exception_Decl', 'Exception_Handler', 'For_Loop_Var_Decl', 'Generic_Decl', 'Generic_Package_Decl', 'Generic_Subp_Decl', 'Generic_Instantiation', 'Generic_Package_Instantiation', 'Generic_Subp_Instantiation', 'Generic_Renaming_Decl', 'Generic_Package_Renaming_Decl', 'Generic_Subp_Renaming_Decl', 'Label_Decl', 'Named_Stmt_Decl', 'Number_Decl', 'Object_Decl', 'Extended_Return_Stmt_Object_Decl', 'No_Type_Object_Renaming_Decl', 'Package_Renaming_Decl', 'Single_Protected_Decl', 'Single_Task_Decl', 'Case_Stmt_Alternative', 'Compilation_Unit', 'Component_Clause', 'Component_Def', 'Constant_Node', 'Constant_Absent', 'Constant_Present', 'Constraint', 'Composite_Constraint', 'Delta_Constraint', 'Digits_Constraint', 'Range_Constraint', 'Declarative_Part', 'Private_Part', 'Public_Part', 'Elsif_Expr_Part', 'Elsif_Stmt_Part', 'Expr', 'Abstract_State_Decl_Expr', 'Allocator', 'Base_Aggregate', 'Aggregate', 'Bracket_Aggregate', 'Delta_Aggregate', 'Bracket_Delta_Aggregate', 'Null_Record_Aggregate', 'Bin_Op', 'Relation_Op', 'Box_Expr', 'Case_Expr_Alternative', 'Concat_Op', 'Concat_Operand', 'Cond_Expr', 'Case_Expr', 'If_Expr', 'Contract_Cases', 'Decl_Expr', 'Membership_Expr', 'Name', 'Attribute_Ref', 'Call_Expr', 'Defining_Name', 'Synthetic_Defining_Name', 'Discrete_Subtype_Name', 'Dotted_Name', 'End_Name', 'Explicit_Deref', 'Qual_Expr', 'Reduce_Attribute_Ref', 'Single_Tok_Node', 'Base_Id', 'Char_Literal', 'Identifier', 'Op', 'Op_Abs', 'Op_And', 'Op_And_Then', 'Op_Concat', 'Op_Div', 'Op_Double_Dot', 'Op_Eq', 'Op_Gt', 'Op_Gte', 'Op_In', 'Op_Lt', 'Op_Lte', 'Op_Minus', 'Op_Mod', 'Op_Mult', 'Op_Neq', 'Op_Not', 'Op_Not_In', 'Op_Or', 'Op_Or_Else', 'Op_Plus', 'Op_Pow', 'Op_Rem', 'Op_Xor', 'String_Literal', 'Null_Literal', 'Num_Literal', 'Int_Literal', 'Real_Literal', 'Synthetic_Identifier', 'Target_Name', 'Update_Attribute_Ref', 'Paren_Expr', 'Quantified_Expr', 'Raise_Expr', 'Un_Op', 'Handled_Stmts', 'Interface_Kind', 'Interface_Kind_Limited', 'Interface_Kind_Protected', 'Interface_Kind_Synchronized', 'Interface_Kind_Task', 'Iter_Type', 'Iter_Type_In', 'Iter_Type_Of', 'Library_Item', 'Limited_Node', 'Limited_Absent', 'Limited_Present', 'Loop_Spec', 'For_Loop_Spec', 'While_Loop_Spec', 'Mode', 'Mode_Default', 'Mode_In', 'Mode_In_Out', 'Mode_Out', 'Multi_Abstract_State_Decl', 'Not_Null', 'Not_Null_Absent', 'Not_Null_Present', 'Null_Component_Decl', 'Others_Designator', 'Overriding_Node', 'Overriding_Not_Overriding', 'Overriding_Overriding', 'Overriding_Unspecified', 'Params', 'Paren_Abstract_State_Decl', 'Pp_Directive', 'Pp_Else_Directive', 'Pp_Elsif_Directive', 'Pp_End_If_Directive', 'Pp_If_Directive', 'Pp_Then_Kw', 'Pragma_Node', 'Private_Node', 'Private_Absent', 'Private_Present', 'Protected_Def', 'Protected_Node', 'Protected_Absent', 'Protected_Present', 'Quantifier', 'Quantifier_All', 'Quantifier_Some', 'Range_Spec', 'Renaming_Clause', 'Synthetic_Renaming_Clause', 'Reverse_Node', 'Reverse_Absent', 'Reverse_Present', 'Select_When_Part', 'Stmt', 'Composite_Stmt', 'Accept_Stmt', 'Accept_Stmt_With_Stmts', 'Base_Loop_Stmt', 'For_Loop_Stmt', 'Loop_Stmt', 'While_Loop_Stmt', 'Block_Stmt', 'Begin_Block', 'Decl_Block', 'Case_Stmt', 'Extended_Return_Stmt', 'If_Stmt', 'Named_Stmt', 'Select_Stmt', 'Error_Stmt', 'Simple_Stmt', 'Abort_Stmt', 'Assign_Stmt', 'Call_Stmt', 'Delay_Stmt', 'Exit_Stmt', 'Goto_Stmt', 'Label', 'Null_Stmt', 'Raise_Stmt', 'Requeue_Stmt', 'Return_Stmt', 'Terminate_Alternative', 'Subp_Kind', 'Subp_Kind_Function', 'Subp_Kind_Procedure', 'Subunit', 'Synchronized_Node', 'Synchronized_Absent', 'Synchronized_Present', 'Tagged_Node', 'Tagged_Absent', 'Tagged_Present', 'Task_Def', 'Type_Attributes_Repository', 'Type_Def', 'Access_Def', 'Access_To_Subp_Def', 'Base_Type_Access_Def', 'Anonymous_Type_Access_Def', 'Type_Access_Def', 'Array_Type_Def', 'Derived_Type_Def', 'Enum_Type_Def', 'Formal_Discrete_Type_Def', 'Interface_Type_Def', 'Mod_Int_Type_Def', 'Private_Type_Def', 'Real_Type_Def', 'Decimal_Fixed_Point_Def', 'Floating_Point_Def', 'Ordinary_Fixed_Point_Def', 'Record_Type_Def', 'Signed_Int_Type_Def', 'Type_Expr', 'Anonymous_Type', 'Enum_Lit_Synth_Type_Expr', 'Subtype_Indication', 'Constrained_Subtype_Indication', 'Discrete_Subtype_Indication', 'Synthetic_Type_Expr', 'Unconstrained_Array_Index', 'Until_Node', 'Until_Absent', 'Until_Present', 'Use_Clause', 'Use_Package_Clause', 'Use_Type_Clause', 'Value_Sequence', 'Variant', 'Variant_Part', 'With_Clause', 'With_Private', 'With_Private_Absent', 'With_Private_Present'],
        astnode_kinds={1: 'Abort_Absent', 2: 'Abort_Present', 3: 'Abstract_Absent', 4: 'Abstract_Present', 5: 'Ada_Node_List', 6: 'Abstract_State_Decl_List', 7: 'Alternatives_List', 8: 'Constraint_List', 9: 'Decl_List', 10: 'Stmt_List', 11: 'Aspect_Assoc_List', 12: 'Base_Assoc_List', 13: 'Assoc_List', 14: 'Basic_Decl_List', 15: 'Case_Expr_Alternative_List', 16: 'Case_Stmt_Alternative_List', 17: 'Compilation_Unit_List', 18: 'Concat_Operand_List', 19: 'Contract_Case_Assoc_List', 20: 'Defining_Name_List', 21: 'Discriminant_Spec_List', 22: 'Elsif_Expr_Part_List', 23: 'Elsif_Stmt_Part_List', 24: 'Enum_Literal_Decl_List', 25: 'Expr_Alternatives_List', 26: 'Discriminant_Choice_List', 27: 'Name_List', 28: 'Parent_List', 29: 'Param_Spec_List', 30: 'Pragma_Node_List', 31: 'Select_When_Part_List', 32: 'Unconstrained_Array_Index_List', 33: 'Variant_List', 34: 'Aliased_Absent', 35: 'Aliased_Present', 36: 'All_Absent', 37: 'All_Present', 38: 'Constrained_Array_Indices', 39: 'Unconstrained_Array_Indices', 40: 'Aspect_Assoc', 41: 'At_Clause', 42: 'Attribute_Def_Clause', 43: 'Enum_Rep_Clause', 44: 'Record_Rep_Clause', 45: 'Aspect_Spec', 46: 'Contract_Case_Assoc', 47: 'Pragma_Argument_Assoc', 48: 'Entry_Spec', 49: 'Enum_Subp_Spec', 50: 'Subp_Spec', 51: 'Synthetic_Binary_Spec', 52: 'Synthetic_Unary_Spec', 53: 'Component_List', 54: 'Known_Discriminant_Part', 55: 'Unknown_Discriminant_Part', 56: 'Entry_Completion_Formal_Params', 57: 'Generic_Formal_Part', 58: 'Null_Record_Def', 59: 'Record_Def', 60: 'Aggregate_Assoc', 61: 'Multi_Dim_Array_Assoc', 62: 'Composite_Constraint_Assoc', 63: 'Iterated_Assoc', 64: 'Param_Assoc', 65: 'Abstract_State_Decl', 66: 'Anonymous_Expr_Decl', 67: 'Component_Decl', 68: 'Discriminant_Spec', 69: 'Generic_Formal_Obj_Decl', 70: 'Generic_Formal_Package', 71: 'Generic_Formal_Subp_Decl', 72: 'Generic_Formal_Type_Decl', 73: 'Param_Spec', 74: 'Synthetic_Formal_Param_Decl', 75: 'Generic_Package_Internal', 76: 'Package_Decl', 77: 'Discrete_Base_Subtype_Decl', 78: 'Subtype_Decl', 79: 'Classwide_Type_Decl', 80: 'Incomplete_Type_Decl', 81: 'Incomplete_Formal_Type_Decl', 82: 'Incomplete_Tagged_Type_Decl', 83: 'Protected_Type_Decl', 84: 'Task_Type_Decl', 85: 'Single_Task_Type_Decl', 86: 'Anonymous_Type_Decl', 87: 'Synth_Anonymous_Type_Decl', 88: 'Concrete_Type_Decl', 89: 'Formal_Type_Decl', 90: 'Abstract_Subp_Decl', 91: 'Abstract_Formal_Subp_Decl', 92: 'Concrete_Formal_Subp_Decl', 93: 'Subp_Decl', 94: 'Entry_Decl', 95: 'Enum_Literal_Decl', 96: 'Synthetic_Char_Enum_Lit', 97: 'Generic_Subp_Internal', 98: 'Synthetic_Subp_Decl', 99: 'Accept_Stmt_Body', 100: 'Expr_Function', 101: 'Null_Subp_Decl', 102: 'Subp_Body', 103: 'Subp_Renaming_Decl', 104: 'Package_Body_Stub', 105: 'Protected_Body_Stub', 106: 'Subp_Body_Stub', 107: 'Task_Body_Stub', 108: 'Entry_Body', 109: 'Package_Body', 110: 'Protected_Body', 111: 'Task_Body', 112: 'Entry_Index_Spec', 113: 'Error_Decl', 114: 'Exception_Decl', 115: 'Exception_Handler', 116: 'For_Loop_Var_Decl', 117: 'Generic_Package_Decl', 118: 'Generic_Subp_Decl', 119: 'Generic_Package_Instantiation', 120: 'Generic_Subp_Instantiation', 121: 'Generic_Package_Renaming_Decl', 122: 'Generic_Subp_Renaming_Decl', 123: 'Label_Decl', 124: 'Named_Stmt_Decl', 125: 'Number_Decl', 126: 'Object_Decl', 127: 'Extended_Return_Stmt_Object_Decl', 128: 'No_Type_Object_Renaming_Decl', 129: 'Package_Renaming_Decl', 130: 'Single_Protected_Decl', 131: 'Single_Task_Decl', 132: 'Case_Stmt_Alternative', 133: 'Compilation_Unit', 134: 'Component_Clause', 135: 'Component_Def', 136: 'Constant_Absent', 137: 'Constant_Present', 138: 'Composite_Constraint', 139: 'Delta_Constraint', 140: 'Digits_Constraint', 141: 'Range_Constraint', 142: 'Declarative_Part', 143: 'Private_Part', 144: 'Public_Part', 145: 'Elsif_Expr_Part', 146: 'Elsif_Stmt_Part', 147: 'Abstract_State_Decl_Expr', 148: 'Allocator', 149: 'Aggregate', 150: 'Bracket_Aggregate', 151: 'Delta_Aggregate', 152: 'Bracket_Delta_Aggregate', 153: 'Null_Record_Aggregate', 154: 'Bin_Op', 155: 'Relation_Op', 156: 'Box_Expr', 157: 'Case_Expr_Alternative', 158: 'Concat_Op', 159: 'Concat_Operand', 160: 'Case_Expr', 161: 'If_Expr', 162: 'Contract_Cases', 163: 'Decl_Expr', 164: 'Membership_Expr', 165: 'Attribute_Ref', 166: 'Call_Expr', 167: 'Defining_Name', 168: 'Synthetic_Defining_Name', 169: 'Discrete_Subtype_Name', 170: 'Dotted_Name', 171: 'End_Name', 172: 'Explicit_Deref', 173: 'Qual_Expr', 174: 'Reduce_Attribute_Ref', 175: 'Char_Literal', 176: 'Identifier', 177: 'Op_Abs', 178: 'Op_And', 179: 'Op_And_Then', 180: 'Op_Concat', 181: 'Op_Div', 182: 'Op_Double_Dot', 183: 'Op_Eq', 184: 'Op_Gt', 185: 'Op_Gte', 186: 'Op_In', 187: 'Op_Lt', 188: 'Op_Lte', 189: 'Op_Minus', 190: 'Op_Mod', 191: 'Op_Mult', 192: 'Op_Neq', 193: 'Op_Not', 194: 'Op_Not_In', 195: 'Op_Or', 196: 'Op_Or_Else', 197: 'Op_Plus', 198: 'Op_Pow', 199: 'Op_Rem', 200: 'Op_Xor', 201: 'String_Literal', 202: 'Null_Literal', 203: 'Int_Literal', 204: 'Real_Literal', 205: 'Synthetic_Identifier', 206: 'Target_Name', 207: 'Update_Attribute_Ref', 208: 'Paren_Expr', 209: 'Quantified_Expr', 210: 'Raise_Expr', 211: 'Un_Op', 212: 'Handled_Stmts', 213: 'Interface_Kind_Limited', 214: 'Interface_Kind_Protected', 215: 'Interface_Kind_Synchronized', 216: 'Interface_Kind_Task', 217: 'Iter_Type_In', 218: 'Iter_Type_Of', 219: 'Library_Item', 220: 'Limited_Absent', 221: 'Limited_Present', 222: 'For_Loop_Spec', 223: 'While_Loop_Spec', 224: 'Mode_Default', 225: 'Mode_In', 226: 'Mode_In_Out', 227: 'Mode_Out', 228: 'Multi_Abstract_State_Decl', 229: 'Not_Null_Absent', 230: 'Not_Null_Present', 231: 'Null_Component_Decl', 232: 'Others_Designator', 233: 'Overriding_Not_Overriding', 234: 'Overriding_Overriding', 235: 'Overriding_Unspecified', 236: 'Params', 237: 'Paren_Abstract_State_Decl', 238: 'Pp_Else_Directive', 239: 'Pp_Elsif_Directive', 240: 'Pp_End_If_Directive', 241: 'Pp_If_Directive', 242: 'Pp_Then_Kw', 243: 'Pragma_Node', 244: 'Private_Absent', 245: 'Private_Present', 246: 'Protected_Def', 247: 'Protected_Absent', 248: 'Protected_Present', 249: 'Quantifier_All', 250: 'Quantifier_Some', 251: 'Range_Spec', 252: 'Renaming_Clause', 253: 'Synthetic_Renaming_Clause', 254: 'Reverse_Absent', 255: 'Reverse_Present', 256: 'Select_When_Part', 257: 'Accept_Stmt', 258: 'Accept_Stmt_With_Stmts', 259: 'For_Loop_Stmt', 260: 'Loop_Stmt', 261: 'While_Loop_Stmt', 262: 'Begin_Block', 263: 'Decl_Block', 264: 'Case_Stmt', 265: 'Extended_Return_Stmt', 266: 'If_Stmt', 267: 'Named_Stmt', 268: 'Select_Stmt', 269: 'Error_Stmt', 270: 'Abort_Stmt', 271: 'Assign_Stmt', 272: 'Call_Stmt', 273: 'Delay_Stmt', 274: 'Exit_Stmt', 275: 'Goto_Stmt', 276: 'Label', 277: 'Null_Stmt', 278: 'Raise_Stmt', 279: 'Requeue_Stmt', 280: 'Return_Stmt', 281: 'Terminate_Alternative', 282: 'Subp_Kind_Function', 283: 'Subp_Kind_Procedure', 284: 'Subunit', 285: 'Synchronized_Absent', 286: 'Synchronized_Present', 287: 'Tagged_Absent', 288: 'Tagged_Present', 289: 'Task_Def', 290: 'Type_Attributes_Repository', 291: 'Access_To_Subp_Def', 292: 'Anonymous_Type_Access_Def', 293: 'Type_Access_Def', 294: 'Array_Type_Def', 295: 'Derived_Type_Def', 296: 'Enum_Type_Def', 297: 'Formal_Discrete_Type_Def', 298: 'Interface_Type_Def', 299: 'Mod_Int_Type_Def', 300: 'Private_Type_Def', 301: 'Decimal_Fixed_Point_Def', 302: 'Floating_Point_Def', 303: 'Ordinary_Fixed_Point_Def', 304: 'Record_Type_Def', 305: 'Signed_Int_Type_Def', 306: 'Anonymous_Type', 307: 'Enum_Lit_Synth_Type_Expr', 308: 'Subtype_Indication', 309: 'Constrained_Subtype_Indication', 310: 'Discrete_Subtype_Indication', 311: 'Synthetic_Type_Expr', 312: 'Unconstrained_Array_Index', 313: 'Until_Absent', 314: 'Until_Present', 315: 'Use_Package_Clause', 316: 'Use_Type_Clause', 317: 'Value_Sequence', 318: 'Variant', 319: 'Variant_Part', 320: 'With_Clause', 321: 'With_Private_Absent', 322: 'With_Private_Present'},
        prefix='lal'
    )
